---
name: r.describe
description: Prints terse list of category values found in a raster map layer.
keywords: [ raster, metadata ]
---

# r.describe

Prints terse list of category values found in a raster map layer.

=== "Command line"

    **r.describe**
    [**-1rndi**]
    **map**=*name*
    [**null_value**=*string*]
    [**nsteps**=*integer*]
    **format**=*name*
    [**--verbose**]
    [**--quiet**]
    [**--qq**]
    [**--ui**]

    Example:

    ```sh
    r.describe map=name format=plain
    ```

=== "Python (grass.script)"

    *grass.script.parse_command*("***r.describe***",
        **map**,
        **null_value**=*"\*"*,
        **nsteps**=*255*,
        **format**=*"plain"*,
        **flags**=*None*,
        **verbose**=*False*,
        **quiet**=*False*,
        **superquiet**=*False*)

    Example:

    ```python
    gs.parse_command("r.describe", map="name", format="json")
    ```

## Parameters

=== "Command line"

    **map**=*name* **[required]**  
    &nbsp;&nbsp;&nbsp;&nbsp;Name of raster map  
    **null_value**=*string*  
    &nbsp;&nbsp;&nbsp;&nbsp;String representing NULL value  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *\**  
    **nsteps**=*integer*  
    &nbsp;&nbsp;&nbsp;&nbsp;Number of quantization steps  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *255*  
    **format**=*name* **[required]**  
    &nbsp;&nbsp;&nbsp;&nbsp;Output format  
    &nbsp;&nbsp;&nbsp;&nbsp;Allowed values: *plain, json*  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *plain*  
    &nbsp;&nbsp;&nbsp;&nbsp;**plain**: Plain text output  
    &nbsp;&nbsp;&nbsp;&nbsp;**json**: JSON (JavaScript Object Notation)  
    **-1**  
    &nbsp;&nbsp;&nbsp;&nbsp;Print the output one value per line  
    **-r**  
    &nbsp;&nbsp;&nbsp;&nbsp;Only print the range of the data  
    **-n**  
    &nbsp;&nbsp;&nbsp;&nbsp;Suppress reporting of any NULLs  
    **-d**  
    &nbsp;&nbsp;&nbsp;&nbsp;Use the current region  
    **-i**  
    &nbsp;&nbsp;&nbsp;&nbsp;Read floating-point map as integer  
    **--help**  
    &nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
    **--verbose**  
    &nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
    **--quiet**  
    &nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
    **--qq**  
    &nbsp;&nbsp;&nbsp;&nbsp;Very quiet module output  
    **--ui**  
    &nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

=== "Python (grass.script)"

    **map** : str, *required*  
    &nbsp;&nbsp;&nbsp;&nbsp;Name of raster map  
    &nbsp;&nbsp;&nbsp;&nbsp;Used as: input, raster, *name*  
    **null_value** : str, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;String representing NULL value  
    &nbsp;&nbsp;&nbsp;&nbsp;Used as: *string*  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *\**  
    **nsteps** : int, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Number of quantization steps  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *255*  
    **format** : str, *required*  
    &nbsp;&nbsp;&nbsp;&nbsp;Output format  
    &nbsp;&nbsp;&nbsp;&nbsp;Used as: *name*  
    &nbsp;&nbsp;&nbsp;&nbsp;Allowed values: *plain, json*  
    &nbsp;&nbsp;&nbsp;&nbsp;**plain**: Plain text output  
    &nbsp;&nbsp;&nbsp;&nbsp;**json**: JSON (JavaScript Object Notation)  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *plain*  
    **flags** : str, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Allowed values: *1*, *r*, *n*, *d*, *i*  
    &nbsp;&nbsp;&nbsp;&nbsp;**1**  
    &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Print the output one value per line  
    &nbsp;&nbsp;&nbsp;&nbsp;**r**  
    &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Only print the range of the data  
    &nbsp;&nbsp;&nbsp;&nbsp;**n**  
    &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Suppress reporting of any NULLs  
    &nbsp;&nbsp;&nbsp;&nbsp;**d**  
    &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Use the current region  
    &nbsp;&nbsp;&nbsp;&nbsp;**i**  
    &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Read floating-point map as integer  
    **verbose**: bool, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *False*  
    **quiet**: bool, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *False*  
    **superquiet**: bool, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Very quiet module output  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *False*

## DESCRIPTION

***r.describe*** prints a terse listing of category values found in a
user-specified raster map layer.

***r.describe*** ignores the current geographic region and mask, and
reads the full extent of the input raster map. This functionality is
useful if the user intends to *reclassify* or *rescale* the data, since
these functions (*[r.reclass](r.reclass.md)* and
*[r.rescale](r.rescale.md)*) also ignore the current *geographic region*
and *mask*.

The ***nv*** parameter sets the string to be used to represent `NULL`
values in the module output; the default is '\*'.

The ***nsteps*** parameter sets the number of quantisation steps to
divide into the input raster map.

## NOTES

### FLAGS

If the user selects the **-r** flag, a range of category values found in
the raster map layer will be printed. The range is divided into three
groups: negative, positive, and zero. If negative values occur, the
minimum and maximum negative values will be printed. If positive values
occur, the minimum and maximum positive values will be printed. If zero
occurs, this will be indicated. The range report will generally run
faster than the full list (the default output).

The **-d** flag can be used to force *r.describe* to respect the current
region extents when reporting raster map categories. The default behavior
is to read the full extent of the input raster map.

If the **-1** flag is specified, the output appears with one category
value/range per line.

The **-n** flag suppresses the reporting of `NULL` values.

## EXAMPLES

The following examples are from the Spearfish60 sample dataset:

### Print the full list of raster map categories

```sh
r.describe landcover.30m
* 11 21-23 31 32 41-43 51 71 81-83 85 91 92
```

### Print the raster range only

```sh
r.describe -r landcover.30m
11 thru 92
*
```

### Print raster map category range, suppressing nulls

```sh
r.describe -n landcover.30m
11 21-23 31 32 41-43 51 71 81-83 85 91 92
```

### Print raster map categories, one category per line

```sh
r.describe -1 geology

*
1
2
3
4
5
6
7
8
9
```

## SEE ALSO

*[g.region](g.region.md), [r.mask](r.mask.md),
[r.reclass](r.reclass.md), [r.report](r.report.md),
[r.rescale](r.rescale.md), [r.stats](r.stats.md),
[r.univar](r.univar.md)*

## AUTHOR

Michael Shapiro, U.S. Army Construction Engineering Research Laboratory

## SOURCE CODE

Available at: [r.describe source code](https://github.com/OSGeo/grass/tree/main/raster/r.describe)
([history](https://github.com/OSGeo/grass/commits/main/raster/r.describe))  
Latest change: Friday Mar 07 07:39:48 2025 in commit [e1e37d8](https://github.com/OSGeo/grass/commit/e1e37d87e78212dfcf4c97aaf32c54042adbd2b0)
