---
name: r.what.color
description: Queries colors for a raster map layer.
keywords: [ raster, querying, color table ]
---

# r.what.color

Queries colors for a raster map layer.

=== "Command line"

    **r.what.color**
    [**-i**]
    **input**=*name*
    [**value**=*float* [,*float*,...]]
    [**format**=*string*]
    [**--verbose**]
    [**--quiet**]
    [**--qq**]
    [**--ui**]

    Example:

    ```sh
    r.what.color input=name
    ```

=== "Python (grass.script)"

    *grass.script.run_command*("***r.what.color***",
        **input**,
        **value**=*None*,
        **format**=*"%d:%d:%d"*,
        **flags**=*None*,
        **verbose**=*False*,
        **quiet**=*False*,
        **superquiet**=*False*)

    Example:

    ```python
    gs.run_command("r.what.color", input="name")
    ```

## Parameters

=== "Command line"

    **input**=*name* **[required]**  
    &nbsp;&nbsp;&nbsp;&nbsp;Name of input raster map  
    **value**=*float* [,*float*,...]  
    &nbsp;&nbsp;&nbsp;&nbsp;Values to query colors for  
    **format**=*string*  
    &nbsp;&nbsp;&nbsp;&nbsp;Output format (printf-style)  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *%d:%d:%d*  
    **-i**  
    &nbsp;&nbsp;&nbsp;&nbsp;Read values from stdin  
    **--help**  
    &nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
    **--verbose**  
    &nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
    **--quiet**  
    &nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
    **--qq**  
    &nbsp;&nbsp;&nbsp;&nbsp;Very quiet module output  
    **--ui**  
    &nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

=== "Python (grass.script)"

    **input** : str, *required*  
    &nbsp;&nbsp;&nbsp;&nbsp;Name of input raster map  
    &nbsp;&nbsp;&nbsp;&nbsp;Used as: input, raster, *name*  
    **value** : float | list[float] | str, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Values to query colors for  
    **format** : str, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Output format (printf-style)  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *%d:%d:%d*  
    **flags** : str, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Allowed values: *i*  
    &nbsp;&nbsp;&nbsp;&nbsp;**i**  
    &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Read values from stdin  
    **verbose**: bool, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *False*  
    **quiet**: bool, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *False*  
    **superquiet**: bool, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Very quiet module output  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *False*

## DESCRIPTION

*r.what.color* outputs the color associated with user-specified category
values in a raster input map.

Values may be specified either using the **values=** option, or by
specifying the **-i** flag and passing the values on `stdin`, one per
line.

For each value which is specified, a line of output will be generated
consisting of the category value followed by the color, e.g.:

```sh
r.what.color input=elevation.dem value=1500
1500: 223:127:31
```

If the input map is an integer (CELL) map, the category will be written
as an integer (no decimal point), otherwise it will be written in
floating point format (*printf("%.15g")* format).

If the lookup fails for a value, the color will be output as an
asterisk, e.g.:

```sh
r.what.color input=elevation.dem value=9999
9999: *
```

If a value cannot be parsed, both the value and the color will be output
as an asterisk, e.g.:

```sh
r.what.color input=elevation.dem value=bogus
*: *
```

The format can be changed using the **format=** option. The value should
be a *printf()*-style format string containing three conversion
specifiers for the red, green and blue values respectively, e.g.:

```sh
r.what.color input=elevation.dem value=1500 format='%02x:%02x:%02x'
1500: df:7f:1f
```

If your system supports the *%m\$* syntax, you can change the ordering
of the components, e.g.:

```sh
r.what.color input=elevation.dem value=1500 format='%3$02x:%2$02x:%1$02x'
1500: 1f:7f:df
```

Common formats:  

- Tcl/Tk: `format="#%02x%02x%02x"`
- WxPython: `format='"#%02x%02x%02x"'` or `format='"(%d,%d,%d)"'`

## SEE ALSO

*[r.what](r.what.md)*

## AUTHOR

Glynn Clements

## SOURCE CODE

Available at: [r.what.color source code](https://github.com/OSGeo/grass/tree/main/raster/r.what.color)
([history](https://github.com/OSGeo/grass/commits/main/raster/r.what.color))  
Latest change: Monday Apr 14 08:16:56 2025 in commit [a22aabd](https://github.com/OSGeo/grass/commit/a22aabdd2fb7243cec03a1df6677078899a18612)
